%define module_name SQLAlchemy
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

Summary:	SQL toolkit and object relational mapper for Python
Name:		python-sqlalchemy
Version:	1.1.4
Release:	%mkrel 1
License:	MIT
Group:		Development/Python
URL:		http://www.sqlalchemy.org/
Source0:	https://pypi.io/packages/source/S/%{module_name}/%{module_name}-%{version}.tar.gz

BuildRequires:	python-setuptools
BuildRequires:	python-pytest
BuildRequires:	python-mock
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:	python3-pytest
BuildRequires:	python3-mock
# Tests fail with earlier versions of sqlite3.
# See: https://bitbucket.org/zzzeek/sqlalchemy/issues/3688
BuildRequires:	pkgconfig(sqlite3) >= 3.12.1
%ifarch x86_64
BuildRequires:	lib64sqlite3_0 >= 3.12.1
%else
BuildRequires:	libsqlite3_0 >= 3.12.1
%endif


%description
%{module_name} is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases.  Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.
This package includes the python 2 version of the module.


%package -n python3-sqlalchemy
Summary:	Modular and flexible ORM library for python
Group:		Development/Python


%description -n python3-sqlalchemy
SQLAlchemy is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases.  Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.
This package includes the python 3 version of the module.


%prep
%setup -q -n %{module_name}-%{version}


%build
%py2_build
%py3_build


%install
%py2_install
%py3_install
# remove unnecessary scripts for building documentation
rm -rf doc/build


%check
pytest2="py.test-$(%{__python2} -c 'from __future__ import print_function; import sys; vi=sys.version_info; print("{0}.{1}".format(vi.major, vi.minor))')"
PYTHONPATH=. "$pytest2" test
pytest3="py.test-$(%{__python3} -c 'from __future__ import print_function; import sys; vi=sys.version_info; print("{0}.{1}".format(vi.major, vi.minor))')"
PYTHONPATH=. "$pytest3" test


%files
%doc README.rst LICENSE PKG-INFO CHANGES doc examples
%{python2_sitearch}/*


%files -n python3-sqlalchemy
%doc LICENSE PKG-INFO doc examples
%{python3_sitearch}/*



%changelog
* Sun Nov 27 2016 philippem <philippem> 1.1.4-1.mga6
+ Revision: 1070407
- update to 1.1.4

* Tue May 17 2016 philippem <philippem> 1.0.13-1.mga6
+ Revision: 1016371
- update to 1.0.13

* Sat Apr 09 2016 shlomif <shlomif> 1.0.12-3.mga6
+ Revision: 999850
- Hopefully fix BR
- Reenable the tests for new sqlite3

* Mon Apr 04 2016 shlomif <shlomif> 1.0.12-2.mga6
+ Revision: 998323
- Avoid running the tests for the current version, due to the new sqlite.

* Tue Feb 16 2016 philippem <philippem> 1.0.12-1.mga6
+ Revision: 962577
- update to 1.0.12

* Wed Dec 23 2015 philippem <philippem> 1.0.11-1.mga6
+ Revision: 913855
- update to 1.0.11

* Sat Dec 19 2015 philippem <philippem> 1.0.10-1.mga6
+ Revision: 912171
- update to 1.0.10

* Thu Oct 29 2015 tv <tv> 1.0.9-1.mga6
+ Revision: 896216
- new release

* Fri Oct 09 2015 shlomif <shlomif> 1.0.8-2.mga6
+ Revision: 888347
- Rebuild for new Python3 (3.5.x)

* Fri Aug 28 2015 philippem <philippem> 1.0.8-1.mga6
+ Revision: 870572
- update to 1.0.8

* Wed Oct 15 2014 umeabot <umeabot> 0.9.7-4.mga5
+ Revision: 747420
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.9.7-3.mga5
+ Revision: 729827
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.9.7-2.mga5
+ Revision: 688349
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 philippem <philippem> 0.9.7-1.mga5
+ Revision: 660836
- update to 0.9.7

* Thu Jul 03 2014 philippem <philippem> 0.9.6-1.mga5
+ Revision: 642777
- update to 0.9.6

* Tue Jun 03 2014 philippem <philippem> 0.9.4-1.mga5
+ Revision: 632655
- update to 0.9.4

  + pterjan <pterjan>
    - Rebuild for new Python

* Mon Mar 17 2014 philippem <philippem> 0.9.3-1.mga5
+ Revision: 604539
- Update to 0.9.3

* Tue Oct 22 2013 umeabot <umeabot> 0.8.2-3.mga4
+ Revision: 544352
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.8.2-2.mga4
+ Revision: 499431
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 10 2013 philippem <philippem> 0.8.2-1.mga4
+ Revision: 452446
- Update to 0.8.2, add Python 3

* Sat Feb 16 2013 philippem <philippem> 0.7.10-1.mga3
+ Revision: 398743
- Update to new upstream

* Sun Jan 13 2013 umeabot <umeabot> 0.7.9-2.mga3
+ Revision: 379545
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 0.7.9-1.mga3
+ Revision: 334189
- Update to 0.7.9

* Sat Dec 17 2011 philippem <philippem> 0.7.4-1.mga2
+ Revision: 183152
- Update to 0.7.4

* Fri Nov 18 2011 philippem <philippem> 0.7.3-1.mga2
+ Revision: 168699
- Update to 0.7.3

* Wed Sep 21 2011 philippem <philippem> 0.7.2-1.mga2
+ Revision: 146407
- 0.7.2 Upstream release
- use sqla_nose.py to fix %%check

* Fri Apr 08 2011 philippem <philippem> 0.6.6-1.mga1
+ Revision: 82011
- imported package python-sqlalchemy

